@@ -557,7 +557,7 @@ logRegMultiClass <- R6::R6Class(
                         term <- c(dep, term)
                         termB64 <- jmvcore::toB64(term)
 
-                        FUN <- list(TRUE); FUN2 <- list(TRUE)
+                        FUN <- list(); FUN2 <- list()
                         cont <- FALSE
 
                         for(k in seq_along(termB64)) {
